ScaleUpWidget constructor
const
ScaleUpWidget({})
Creates a ScaleUpWidget.
The availableHeight parameter specifies the available height for scaling.
The child parameter is the widget to be scaled up. The maxHeight parameter
defines the maximum height for the scaled child widget.
Implementation
const ScaleUpWidget({
super.key,
required this.availableHeight,
required this.child,
required this.maxHeight,
});